@@ -172,12 +172,13 @@ class FileShelf(Shelf):
         """
         We want to return a dict associating fieldname to a list of relevant terms.
         """
-        # We're going to parse through the index, we first need the field list
-        fields = self.index.schema.names()
+        # We're going to parse through the index, we first need the field list, but we want only
+        # the ones with scores
+        fields = self.index.schema.scorable_names()
         schem = {}
 
         # We don't want all of the terms, just the most frequents ones
         with self.index.reader() as reader:
-            schem = {field: reader.most_frequent_terms(field) for field in fields}
+            schem = {field: [term for (a,term) in reader.most_frequent_terms(field, number=10)] for field in fields} 
 
         return schem
